# 组件
> https://discuss.streamlit.io/t/streamlit-components-community-tracker/4634/12

- https://github.com/ChrisDelClea/streamlit-agraph
- https://github.com/streamlit/example-app-pdf-report/blob/main/template.html
- https://zhuanlan.zhihu.com/p/481270979